@@ -69,6 +69,12 @@ static double
 static void
   StopTimer(TimerInfo *);
 
+/*
+  Static declarations.
+*/
+static ssize_t
+  date_precision = -1;
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -257,8 +263,7 @@ MagickExport ssize_t FormatMagickTime(const time_t time,const size_t length,
   char *timestamp)
 {
   ssize_t
-    count,
-    date_precision = -1;
+    count;
 
   struct tm
     utc_time;
@@ -269,15 +274,8 @@ MagickExport ssize_t FormatMagickTime(const time_t time,const size_t length,
       char
         *limit;
 
-      ExceptionInfo
-        *exception = AcquireExceptionInfo();
-
       date_precision=0;
-      limit=(char *) GetImageRegistry(StringRegistryType,"date:precision",
-        exception);
-      exception=DestroyExceptionInfo(exception);
-      if (limit == (char *) NULL)
-        limit=GetEnvironmentValue("MAGICK_DATE_PRECISION");
+      limit=GetEnvironmentValue("MAGICK_DATE_PRECISION");
       if (limit != (char *) NULL)
         {
           date_precision=StringToInteger(limit);
@@ -482,6 +480,33 @@ MagickExport void ResetTimer(TimerInfo *time_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S e t M a g i c k D a t e P r e c i s i o n                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetMagickDatePrecision() sets the pseudo-random number generator secret key.
+%
+%  The format of the SetMagickDatePrecision method is:
+%
+%      void SetMagickDatePrecision(const unsigned long precision)
+%
+%  A description of each parameter follows:
+%
+%    o key: the date precision.
+%
+*/
+MagickPrivate void SetMagickDatePrecision(const unsigned long precision)
+{
+  date_precision=precision;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   S t a r t T i m e r                                                       %
 %                                                                             %
 %                                                                             %
