@@ -41,6 +41,7 @@
 */
 #include "MagickCore/studio.h"
 #include "MagickCore/attribute.h"
+#include "MagickCore/artifact.h"
 #include "MagickCore/cache.h"
 #include "MagickCore/cache-view.h"
 #include "MagickCore/color.h"
@@ -216,11 +217,11 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
   assert(chop_info != (RectangleInfo *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (((chop_info->x+(ssize_t) chop_info->width) < 0) ||
       ((chop_info->y+(ssize_t) chop_info->height) < 0) ||
       (chop_info->x > (ssize_t) image->columns) ||
@@ -435,10 +436,10 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
   */
   assert(images != (Image *) NULL);
   assert(images->signature == MagickCoreSignature);
-  if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   cmyk_images=NewImageList();
   for (j=0; j < (ssize_t) GetImageListLength(images); j+=4)
   {
@@ -567,11 +568,11 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(geometry != (const RectangleInfo *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   bounding_box=image->page;
   if ((bounding_box.width == 0) || (bounding_box.height == 0))
     {
@@ -794,7 +795,7 @@ MagickExport Image *CropImageToTiles(const Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   flags=ParseGravityGeometry(image,crop_geometry,&geometry,exception);
   if ((flags & AreaValue) != 0)
@@ -1004,11 +1005,11 @@ MagickExport Image *ExcerptImage(const Image *image,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(geometry != (const RectangleInfo *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   excerpt_image=CloneImage(image,geometry->width,geometry->height,MagickTrue,
     exception);
   if (excerpt_image == (Image *) NULL)
@@ -1132,11 +1133,11 @@ MagickExport Image *ExtentImage(const Image *image,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(geometry != (const RectangleInfo *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   extent_image=CloneImage(image,geometry->width,geometry->height,MagickTrue,
     exception);
   if (extent_image == (Image *) NULL)
@@ -1204,10 +1205,10 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   flip_image=CloneImage(image,0,0,MagickTrue,exception);
   if (flip_image == (Image *) NULL)
     return((Image *) NULL);
@@ -1339,10 +1340,10 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   flop_image=CloneImage(image,0,0,MagickTrue,exception);
   if (flop_image == (Image *) NULL)
     return((Image *) NULL);
@@ -1550,10 +1551,10 @@ MagickExport Image *RollImage(const Image *image,const ssize_t x_offset,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   roll_image=CloneImage(image,0,0,MagickTrue,exception);
   if (roll_image == (Image *) NULL)
     return((Image *) NULL);
@@ -1635,7 +1636,7 @@ MagickExport Image *ShaveImage(const Image *image,
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (((2*shave_info->width) >= image->columns) ||
       ((2*shave_info->height) >= image->rows))
@@ -1714,7 +1715,7 @@ MagickExport Image *SpliceImage(const Image *image,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(geometry != (const RectangleInfo *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
@@ -2045,7 +2046,7 @@ MagickPrivate MagickBooleanType TransformImage(Image **image,
 
   assert(image != (Image **) NULL);
   assert((*image)->signature == MagickCoreSignature);
-  if ((*image)->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",(*image)->filename);
   transform_image=(*image);
   if (crop_geometry != (const char *) NULL)
@@ -2136,10 +2137,10 @@ MagickExport Image *TransposeImage(const Image *image,ExceptionInfo *exception)
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   transpose_image=CloneImage(image,image->rows,image->columns,MagickTrue,
     exception);
   if (transpose_image == (Image *) NULL)
@@ -2274,10 +2275,10 @@ MagickExport Image *TransverseImage(const Image *image,ExceptionInfo *exception)
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   transverse_image=CloneImage(image,image->rows,image->columns,MagickTrue,
     exception);
   if (transverse_image == (Image *) NULL)
@@ -2398,15 +2399,19 @@ MagickExport Image *TransverseImage(const Image *image,ExceptionInfo *exception)
 */
 MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
 {
+  const char
+    *artifact;
+
   Image
     *trim_image;
 
   RectangleInfo
-    geometry;
+    geometry,
+    page;
 
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   geometry=GetImageBoundingBox(image,exception);
   if ((geometry.width == 0) || (geometry.height == 0))
@@ -2425,6 +2430,69 @@ MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
       crop_image->page.y=(-1);
       return(crop_image);
     }
+  page=geometry;
+  artifact=GetImageArtifact(image,"trim:minSize");
+  if (artifact != (const char *) NULL)
+    (void) ParseAbsoluteGeometry(artifact,&page);
+  if ((geometry.width < page.width) && (geometry.height < page.height))
+    {
+      /*
+        Limit trim to a minimum size.
+      */
+      switch (image->gravity)
+      {
+        case CenterGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width)/2;
+          geometry.y-=((ssize_t) page.height-geometry.height)/2;
+          break;
+        }
+        case NorthWestGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width);
+          geometry.y-=((ssize_t) page.height-geometry.height);
+          break;
+        }
+        case NorthGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width)/2;
+          geometry.y-=((ssize_t) page.height-geometry.height);
+          break;
+        }
+        case NorthEastGravity:
+        {
+          geometry.y-=((ssize_t) page.height-geometry.height);
+          break;
+        }
+        case EastGravity:
+        {
+          geometry.y-=((ssize_t) page.height-geometry.height)/2;
+          break;
+        }
+        case SouthEastGravity:
+          break;
+        case SouthGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width)/2;
+          break;
+        }
+        case SouthWestGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width);
+          break;
+        }
+        case WestGravity:
+        {
+          geometry.x-=((ssize_t) page.width-geometry.width);
+          geometry.y-=((ssize_t) page.height-geometry.height)/2;
+          break;
+        }
+        default:
+          break;
+      }
+      geometry.width=page.width;
+      geometry.height=page.height;
+    }
   geometry.x+=image->page.x;
   geometry.y+=image->page.y;
   trim_image=CropImage(image,&geometry,exception);
